pub enum PackingError {
InvalidBufferSize,
}Expand description
An error from attempting to pack data into a buffer or from attempting to unpack data from a slice.
Variants
InvalidBufferSize
The buffer to pack or unpack data from cannot be used as the data will not fit in the buffer.